@@ -1,15 +1,16 @@
 package Archive::BagIt;
-our $VERSION = '0.061'; # TRIAL VERSION
+our $VERSION = '0.064'; # TRIAL VERSION
+# ABSTRACT: An interface to make and verify bags according to the BagIt standard
 use strict;
 use warnings;
 use utf8;
-use open ':std', ':utf8';
+use open ':std', ':encoding(UTF-8)';
 our @checksum_algos = qw(md5 sha1);
 our $DEBUG=0;
 use Encode qw(decode);
 use File::Find;
 use Data::Dumper;
-#use Data::Printer;
+
 
 sub new {
   my ($class,$bag_path) = @_;
@@ -37,7 +38,7 @@ sub _load_manifests {
 
   my @manifests = $self->manifest_files();
   foreach my $manifest_file (@manifests) {
-    die("Cannot open $manifest_file: $!") unless (open (my $MANIFEST,"<:encoding(utf8)", $manifest_file));
+    die("Cannot open $manifest_file: $!") unless (open (my $MANIFEST,"<:encoding(UTF-8)", $manifest_file));
     while (my $line = <$MANIFEST>) {
         chomp($line);
         my ($digest,$file);
@@ -61,7 +62,7 @@ sub _load_tagmanifests {
 
   my @tagmanifests = $self->tagmanifest_files();
   foreach my $tagmanifest_file (@tagmanifests) {
-    die("Cannot open $tagmanifest_file: $!") unless (open(my $TAGMANIFEST,"<:encoding(utf8)", $tagmanifest_file));
+    die("Cannot open $tagmanifest_file: $!") unless (open(my $TAGMANIFEST,"<:encoding(UTF-8)", $tagmanifest_file));
     while (my $line = <$TAGMANIFEST>) {
       chomp($line);
       my($digest,$file) = split(/\s+/, $line, 2);
@@ -93,7 +94,7 @@ sub make_bag {
 
 sub _write_bagit {
     my($self, $bagit) = @_;
-    open(my $BAGIT, ">", $bagit."/bagit.txt") or die("Can't open $bagit/bagit.txt for writing: $!");
+    open(my $BAGIT, ">:encoding(UTF-8)", $bagit."/bagit.txt") or die("Can't open $bagit/bagit.txt for writing: $!");
     print($BAGIT "BagIt-Version: 0.97\nTag-File-Character-Encoding: UTF-8");
     close($BAGIT);
     return 1;
@@ -104,7 +105,7 @@ sub _write_bagit {
 sub _write_baginfo {
     use POSIX;
     my($self, $bagit, %param) = @_;
-    open(my $BAGINFO, ">", $bagit."/bag-info.txt") or die("Can't open $bagit/bag-info.txt for writing: $!");
+    open(my $BAGINFO, ">:encoding(UTF-8)", $bagit."/bag-info.txt") or die("Can't open $bagit/bag-info.txt for writing: $!");
     $param{'Bagging-Date'} = POSIX::strftime("%Y-%m-%d", gmtime(time));
     $param{'Bag-Software-Agent'} = 'Archive::BagIt <http://search.cpan.org/~rjeschmi/Archive-BagIt>';
     while(my($key, $value) = each(%param)) {
@@ -121,13 +122,13 @@ sub _manifest_crc32 {
     my $data_dir = "$bagit/data";
 
     # Generate MD5 digests for all of the files under ./data
-    open(my $fh, ">:encoding(utf8)",$manifest_file) or die("Cannot create manifest-crc32.txt: $!\n");
+    open(my $fh, ">:encoding(UTF-8)",$manifest_file) or die("Cannot create manifest-crc32.txt: $!\n");
     find(
         sub {
-            $_=decode('utf8', $_);
-            my $file = decode('utf8', $File::Find::name);
+            $_=decode('UTF-8', $_);
+            my $file = decode('UTF-8', $File::Find::name);
             if (-f $_) {
-                open(my $DATA, "<:encoding(utf8)", $_) or die("Cannot read $_: $!");
+                open(my $DATA, "<:encoding(UTF-8)", $_) or die("Cannot read $_: $!");
                 my $digest = sprintf("%010d",crc32($DATA));
                 close($DATA);
                 my $filename = substr($file, length($bagit) + 1);
@@ -148,10 +149,10 @@ sub _manifest_md5 {
     my $data_dir = "$bagit/data";
     #print "creating manifest: $data_dir\n";
     # Generate MD5 digests for all of the files under ./data
-    open(my $md5_fh, ">:encoding(utf8)",$manifest_file) or die("Cannot create manifest-md5.txt: $!\n");
+    open(my $md5_fh, ">:encoding(UTF-8)",$manifest_file) or die("Cannot create manifest-md5.txt: $!\n");
     find(
         sub {
-            my $file = decode('utf8', $File::Find::name);
+            my $file = decode('UTF-8', $File::Find::name);
             if (-f $_) {
                 open(my $DATA, "<:raw", "$_") or die("Cannot read $_: $!");
                 my $digest = Digest::MD5->new->addfile($DATA)->hexdigest;
@@ -174,12 +175,12 @@ sub _tagmanifest_md5 {
 
   my $tagmanifest_file= "$bagit/tagmanifest-md5.txt";
 
-  open (my $md5_fh, ">:encoding(utf8)", $tagmanifest_file) or die ("Cannot create tagmanifest-md5.txt: $! \n");
+  open (my $md5_fh, ">:encoding(UTF-8)", $tagmanifest_file) or die ("Cannot create tagmanifest-md5.txt: $! \n");
 
   find (
     sub {
-      $_ = decode('utf8',$_);
-      my $file = decode('utf8',$File::Find::name);
+      $_ = decode('UTF-8',$_);
+      my $file = decode('UTF-8',$File::Find::name);
       if ($_=~m/^data$/) {
         $File::Find::prune=1;
       }
@@ -226,7 +227,7 @@ sub verify_bag {
     }
 
     # Compile a list of payload files
-    find(sub{ push(@payload, decode('utf8',$File::Find::name))  }, $payload_dir);
+    find(sub{ push(@payload, decode('UTF-8',$File::Find::name))  }, $payload_dir);
 
     # Evaluate each file against the manifest
     my $digestobj = Digest::MD5->new();
@@ -280,7 +281,7 @@ sub version {
     my($self) = @_;
     my $bagit = $self->{'bag_path'};
     my $file = join("/", $bagit, "bagit.txt");
-    open(my $BAGIT, "<", $file) or die("Cannot read $file: $!");
+    open(my $BAGIT, "<:encoding(UTF-8)", $file) or die("Cannot read $file: $!");
     my $version_string = <$BAGIT>;
     my $encoding_string = <$BAGIT>;
     close($BAGIT);
@@ -303,7 +304,7 @@ sub _payload_files{
   my @payload=();
   File::Find::find( sub{
 
-    push(@payload,decode('utf8',$File::Find::name));
+    push(@payload,decode('UTF-8',$File::Find::name));
     #print "name: ".$File::Find::name."\n";
   }, $payload_dir);
 
@@ -325,7 +326,7 @@ sub _non_payload_files {
 
   my @payload = ();
   File::Find::find( sub {
-    $File::Find::name = decode ('utf8', $File::Find::name);
+    $File::Find::name = decode ('UTF-8', $File::Find::name);
     if(-f $File::Find::name) {
       my ($relpath) = ($File::Find::name=~m!$self->{"bag_path"}/(.*$)!);
       push(@payload, $relpath);
@@ -372,6 +373,7 @@ sub tagmanifest_files {
 }
 
 
+
 1; # End of Archive::BagIt
 
 __END__
@@ -382,40 +384,11 @@ __END__
 
 =head1 NAME
 
-Archive::BagIt
+Archive::BagIt - An interface to make and verify bags according to the BagIt standard
 
 =head1 VERSION
 
-version 0.061
-
-=head1 SYNOPSIS
-
-This modules will hopefully help with the basic commands needed to create
-and verify a bag. My intention is not to be strict and enforce all of the
-specification. The reference implementation is the java version
-and I will endeavour to maintain compatibility with it.
-
-    use Archive::BagIt;
-
-    #read in an existing bag:
-    my $bag_dir = "/path/to/bag";
-    my $bag = Archive::BagIt->new($bag_dir);
-
-
-    #construct bag in an existing directory
-    my $bag2 = Archive::BagIt->make_bag($bag_dir);
-
-    # Validate a BagIt archive against its manifest
-    my $bag3 = Archive::BagIt->new($bag_dir);
-    my $is_valid = $bag3->verify_bag();
-
-=head1 NAME
-
-Archive::BagIt
-
-=head1 VERSION
-
-version 0.061
+version 0.064
 
 =head1 WARNING
 
@@ -427,10 +400,6 @@ support BagIt 1.0 according to RFC 8493 ([https://tools.ietf.org/html/rfc8493](h
 Also: Check out Archive::BagIt::Fast if you are willing to add some extra dependencies to get
 better speed by mmap-ing files.
 
-=head1 NAME
-
-Archive::BagIt - An interface to make and verify bags according to the BagIt standard
-
 =head1 SUBROUTINES
 
 =head2 new
@@ -476,28 +445,6 @@ Return an array with the list of manifest files that exist in the bag
 
 Return an array with the list of tagmanifest files
 
-=head1 AUTHORS
-
-=over
-
-=item Robert Schmidt, E<lt>rjeschmi at gmail.comE<gt>
-
-=item William Wueppelmann, E<lt>william at c7a.caE<gt>
-
-=item Andreas Romeyke, E<lt>pause at andreas minus romeyke.deE<gt>
-
-=back
-
-=head1 CONTRIBUTORS
-
-=over
-
-=item Serhiy Bolkun
-
-=item Russell McOrmond
-
-=back
-
 =head1 SOURCE
 
 The original development version is on github at L<http://github.com/rjeschmi/Archive-BagIt>
@@ -505,12 +452,6 @@ and may be cloned from there.
 
 The actual development version is available at L<https://art1pirat.spdns.org/art1/Archive-BagIt>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-archive-bagit at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Archive-BagIt>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -539,14 +480,26 @@ L<http://search.cpan.org/dist/Archive-BagIt/>
 
 =back
 
-=head1 COPYRIGHT
+=head1 SYNOPSIS
 
-Copyright (c) 2012, the above named author(s).
+This modules will hopefully help with the basic commands needed to create
+and verify a bag. My intention is not to be strict and enforce all of the
+specification. The reference implementation is the java version
+and I will endeavour to maintain compatibility with it.
 
-=head1 LICENSE
+    use Archive::BagIt;
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+    #read in an existing bag:
+    my $bag_dir = "/path/to/bag";
+    my $bag = Archive::BagIt->new($bag_dir);
+
+
+    #construct bag in an existing directory
+    my $bag2 = Archive::BagIt->make_bag($bag_dir);
+
+    # Validate a BagIt archive against its manifest
+    my $bag3 = Archive::BagIt->new($bag_dir);
+    my $is_valid = $bag3->verify_bag();
 
 =head1 AVAILABILITY
 
@@ -554,11 +507,6 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<https://metacpan.org/module/Archive::BagIt/>.
 
-=head1 SOURCE
-
-The development version is on github at L<https://github.com/Archive-BagIt>
-and may be cloned from L<git://github.com/Archive-BagIt.git>
-
 =head1 BUGS AND LIMITATIONS
 
 You can make new bug reports, and view existing ones, through the
@@ -575,15 +523,4 @@ This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and A
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 AUTHOR
-
-Rob Schmidt <rjeschmi@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
