@@ -1,10 +1,8 @@
 package Archive::BagIt::Base;
 use strict;
 use warnings;
-use Moo;
-
 use utf8;
-use open ':std', ':encoding(utf8)';
+use open ':std', ':encoding(UTF-8)';
 use Encode qw(decode);
 use File::Find;
 use File::Spec;
@@ -14,13 +12,14 @@ use Class::Load qw(load_class);
 use Carp;
 use List::Util qw(uniq);
 use POSIX qw(strftime);
+use Moo;
 
-our $VERSION = '0.061'; # TRIAL VERSION
+our $VERSION = '0.064'; # TRIAL VERSION
+
+# ABSTRACT: The common base for Archive::BagIt. This is the module for experts. ;)
 
 use Sub::Quote;
 
-my $DEBUG=0;
-
 
 
 around 'BUILDARGS' , sub {
@@ -33,29 +32,53 @@ around 'BUILDARGS' , sub {
     }
 };
 
+
 sub BUILD {
     my ($self, $args) = @_;
     return $self->load_plugins(("Archive::BagIt::Plugin::Manifest::MD5", "Archive::BagIt::Plugin::Manifest::SHA512"));
 }
 
-
 ###############################################
 
 
 has 'parallel' => ( # used for parallel verify, only usefull if bagits with many files expected!
     is        => 'rw',
-    predicate => 'has_parallel',
-    default   => undef,
+    lazy      => 1,
 );
 
+sub has_parallel {
+    my $self = shift;
+    if ((exists $self->{parallel}) && ($self->{parallel})) {
+        return 1
+    } else {
+        return;
+    }
+}
 
 ###############################################
 
+
+has 'force_utf8' => (
+    is        => 'rw',
+    lazy      => 1,
+);
+
+sub has_force_utf8 {
+    my $self = shift;
+    if ((exists $self->{force_utf8}) && ($self->{force_utf8})) {
+        return 1;
+    } else {
+        return;
+    }
+}
+
+###############################################
+
+
 has 'bag_path' => (
     is => 'rw',
 );
 
-
 ###############################################
 
 has 'bag_path_arr' => (
@@ -66,6 +89,7 @@ has 'bag_path_arr' => (
 
 ###############################################
 
+
 has 'metadata_path' => (
     is=> 'ro',
     lazy => 1,
@@ -77,7 +101,6 @@ sub _build_metadata_path {
     return $self->bag_path;
 }
 
-
 ###############################################
 
 has 'metadata_path_arr' => (
@@ -97,6 +120,7 @@ has 'rel_metadata_path' => (
 
 ###############################################
 
+
 has 'payload_path' => (
     is => 'ro',
     lazy => 1,
@@ -105,10 +129,9 @@ has 'payload_path' => (
 
 sub _build_payload_path {
     my ($self) = @_;
-    return $self->bag_path."/data";
+    return File::Spec->catdir($self->bag_path, "data");
 }
 
-
 ###############################################
 
 has 'payload_path_arr' => (
@@ -127,22 +150,22 @@ has 'rel_payload_path' => (
 
 ###############################################
 
+
 has 'checksum_algos' => (
     is => 'ro',
     lazy => 1,
     builder => '_build_checksum_algos',
 );
 
-
 ###############################################
 
+
 has 'bag_version' => (
     is       => 'ro',
     lazy     => 1,
     builder  => '_build_bag_version',
 );
 
-
 ###############################################
 
 
@@ -152,7 +175,6 @@ has 'bag_encoding' => (
     builder => '_build_bag_encoding',
 );
 
-
 ###############################################
 
 
@@ -163,7 +185,6 @@ has 'bag_info' => (
     predicate => 1
 );
 
-
 ###############################################
 
 
@@ -173,9 +194,9 @@ has 'errors' => (
     builder => sub { my $self = shift; return [];},
 );
 
-
 ###############################################
 
+
 has 'digest_callback' => (
     is      => 'ro',
     lazy    => 1,
@@ -192,59 +213,186 @@ has 'digest_callback' => (
     }
 );
 
-
 ###############################################
 
 
-# bag_info_by_key()
-sub bag_info_by_key {
+sub get_baginfo_values_by_key {
     my ($self, $searchkey) = @_;
     my $info = $self->bag_info();
+    my @values;
     if (defined $searchkey) {
-        foreach my $entry (@{$info}) {
-            if (exists $entry->{$searchkey}) {
-                return $entry->{$searchkey};
+        my $lc_flag = $self->is_baginfo_key_reserved( $searchkey );
+        foreach my $entry (@{ $info }) {
+            my ($key, $value) = %{ $entry };
+            if ( __case_aware_compare_for_baginfo( $key, $searchkey, $lc_flag) ) {
+                push @values, $value;
             }
         }
     }
+    return @values if (scalar(@values) > 0);
     return;
 }
 
-
 ###############################################
 
 
-sub _replace_bag_info_by_first_match {
-    my ($self, $searchkey, $newvalue) = @_;
-    my $info = $self->bag_info();
+sub is_baginfo_key_reserved_as_uniq {
+    my ($self, $searchkey) = @_;
+    return $searchkey =~ m/(Bagging-Date)|(Bag-Size)|(Payload-Oxum)|(Bag-Group-Identifier)|(Bag-Count)/i;
+}
+
+###############################################
+
+
+sub is_baginfo_key_reserved {
+    my ($self, $searchkey) = @_;
+    my @reserved = qw(
+        Source-Organization
+        Organisation-Adress
+        Contact-Name
+        Contact-Phone
+        Contact-Email
+        External-Description
+        Bagging-Date
+        External-Identifier
+        Bag-Size
+        Payload-Oxum
+        Bag-Group-Identifier
+        Bag-Count
+        Internal-Sender-Identifier
+        Internal-Sender-Description
+    );
+    return List::Util::any { (lc $searchkey) eq (lc $_) } @reserved;
+}
+
+###############################################
+
+sub __case_aware_compare_for_baginfo {
+    my ($internal_key, $search_key, $lc_flag) = @_;
+    return (defined $internal_key) && (
+        ( $lc_flag && ((lc $internal_key) eq (lc $search_key)) ) # for reserved keys use caseinsensitive search
+            ||
+            ( (!$lc_flag) && ($internal_key eq $search_key) ) # for other keys sensitive search
+    )
+}
+
+###############################################
+
+sub _find_baginfo_idx {
+    my ($self, $searchkey) = @_;
     if (defined $searchkey) {
-        if ($searchkey =~ m/:/) { croak "key should not contain a colon! (searchkey='$searchkey')"; }
-        my $size = scalar( @{$info});
-        for (my $idx=0; $idx< $size; $idx++) {
-            my %entry = %{ $info->[$idx] };
-            my ($key, $value) = each %entry;
-            if ((defined $key) && ($key eq $searchkey)) {
-                $info->[$idx] = {$searchkey => $newvalue};
+        if ($searchkey =~ m/:/) {croak "key should not contain a colon! (searchkey='$searchkey')";}
+        my $info = $self->bag_info();
+        my $size = scalar(@{$info});
+        my $lc_flag = $self->is_baginfo_key_reserved($searchkey);
+        for (my $idx = 0; $idx < $size; $idx++) {
+            my %entry = %{$info->[$idx]};
+            my ($key, $value) = %entry;
+            if (__case_aware_compare_for_baginfo($key, $searchkey, $lc_flag)) {
                 return $idx;
             }
         }
     }
     return;
 }
+###############################################
 
-sub _add_or_replace_bag_info {
+
+sub verify_baginfo {
+    my ($self) = @_;
+    my %keys;
+    my $info = $self->bag_info();
+    my $ret = 1;
+    if (defined $info) {
+        foreach my $entry (@{$self->bag_info()}) {
+            my ($key, $value) = %{$entry};
+            if ($self->is_baginfo_key_reserved($key)) {
+                $keys{ lc $key }++;
+            }
+            else {
+                $keys{ $key }++
+            }
+        }
+        foreach my $key (keys %keys) {
+            if ($self->is_baginfo_key_reserved_as_uniq($key)) {
+                if ($keys{$key} > 1) {
+                    push @{$self->{errors}}, "Baginfo key '$key' exists $keys{$key}, but should be uniq!";
+                    $ret = undef;
+                }
+            }
+        }
+    }
+    return $ret;
+}
+
+###############################################
+
+
+sub delete_baginfo_by_key {
+    my ($self, $searchkey) = @_;
+    my $idx = $self->_find_baginfo_idx($searchkey);
+    if (defined $idx) {
+        delete $self->{bag_info}[$idx];
+    }
+    return 1;
+}
+
+###############################################
+
+
+sub exists_baginfo_key {
+    my ($self, $searchkey) =@_;
+    return (defined  $self->_find_baginfo_idx($searchkey));
+}
+
+###############################################
+
+sub _replace_baginfo_by_first_match {
+    my ($self, $searchkey, $newvalue) = @_;
+    my $idx = $self->_find_baginfo_idx( $searchkey);
+    if (defined $idx) {
+        $self->{bag_info}[$idx] = {$searchkey => $newvalue};
+        return $idx;
+    }
+    return;
+}
+
+###############################################
+
+
+sub append_baginfo_by_key {
+    my ($self, $searchkey, $newvalue) = @_;
+    if (defined $searchkey) {
+        if ($searchkey =~ m/:/) { croak "key should not contain a colon! (searchkey='$searchkey')"; }
+        if ($self->is_baginfo_key_reserved_as_uniq($searchkey)) {
+            if (defined $self->get_baginfo_values_by_key($searchkey)) {
+                # hmm, search key is mrked as uniq and still exists
+                return;
+            }
+        }
+        push @{$self->{bag_info}}, {$searchkey => $newvalue};
+    }
+    return 1;
+}
+
+###############################################
+
+
+sub add_or_replace_baginfo_by_key {
     my ($self, $searchkey, $newvalue) = @_;
     if (defined $searchkey) {
         if ($searchkey =~ m/:/) { croak "key should not contain a colon! (searchkey='$searchkey')"; }
         if (defined $self->{bag_info}) {
-            my $idx = $self->_replace_bag_info_by_first_match( $searchkey, $newvalue);
+            my $idx = $self->_replace_baginfo_by_first_match( $searchkey, $newvalue);
             if (defined $idx) { return $idx;}
         }
-        push @{$self->{bag_info}}, {$searchkey => $newvalue};
+        $self->append_baginfo_by_key( $searchkey, $newvalue );
         return -1;
     }
 }
 
+###############################################
+
 
 has 'forced_fixity_algorithm' => (
     is   => 'ro',
@@ -252,18 +400,25 @@ has 'forced_fixity_algorithm' => (
     builder  => '_build_forced_fixity_algorithm',
 );
 
+###############################################
+
+
 has 'manifest_files' => (
     is => 'ro',
     lazy => 1,
     builder => '_build_manifest_files',
 );
 
+###############################################
+
+
 has 'tagmanifest_files' => (
     is => 'ro',
     lazy => 1,
     builder => '_build_tagmanifest_files',
 );
 
+###############################################
 
 
 has 'payload_files' => ( # relatively to bagit base
@@ -272,17 +427,27 @@ has 'payload_files' => ( # relatively to bagit base
     builder => '_build_payload_files',
 );
 
+###############################################
+
+
 has 'non_payload_files' => (
     is=>'ro',
     lazy => 1,
     builder => '_build_non_payload_files',
 );
 
+###############################################
+
+
 has 'plugins' => (
     is=>'rw',
     #isa=>'HashRef',
 );
 
+###############################################
+
+
+
 has 'manifests' => (
     is      => 'rw',
     lazy    => 1,
@@ -290,11 +455,16 @@ has 'manifests' => (
     #isa=>'HashRef',
 );
 
+###############################################
+
+
+
 has 'algos' => (
     is=>'rw',
     #isa=>'HashRef',
 );
 
+###############################################
 
 sub _build_bag_path_arr {
     my ($self) = @_;
@@ -336,7 +506,7 @@ sub _build_manifest_files {
   my($self) = @_;
   my @manifest_files;
   foreach my $algo (@{$self->checksum_algos}) {
-    my $manifest_file = File::Spec->catdir($self->metadata_path, "manifest-$algo.txt");
+    my $manifest_file = File::Spec->catfile($self->metadata_path, "manifest-$algo.txt");
     if (-f $manifest_file) {
       push @manifest_files, $manifest_file;
     }
@@ -348,7 +518,7 @@ sub _build_tagmanifest_files {
   my ($self) = @_;
   my @tagmanifest_files;
   foreach my $algo (@{$self->checksum_algos}) {
-    my $tagmanifest_file = File::Spec->catdir($self->metadata_path,"tagmanifest-$algo.txt");
+    my $tagmanifest_file = File::Spec->catfile($self->metadata_path,"tagmanifest-$algo.txt");
     if (-f $tagmanifest_file) {
       push @tagmanifest_files, $tagmanifest_file;
     }
@@ -356,36 +526,65 @@ sub _build_tagmanifest_files {
   return \@tagmanifest_files;
 }
 
-sub _build_payload_files{
-  my($self) = @_;
-  my $payload_dir = $self->payload_path;
-  my @payload=();
-  File::Find::find( sub{
-    $File::Find::name = decode ('utf8', $File::Find::name);
-    $_ = decode ('utf8', $_);
-    if (-f $_) {
-        my $rel_path=File::Spec->catdir($self->rel_payload_path,File::Spec->abs2rel($File::Find::name, $payload_dir));
-        push(@payload,$rel_path);
+sub __file_find { # own implementation, because File::Find has problems with UTF8 encoded Paths under MSWin32
+    # finds recursively all files in given directory.
+    # if $excludedir is defined, the content will be excluded
+    my ($self,$dir, $excludedir) = @_;
+    if (defined $excludedir) {
+        $excludedir = File::Spec->rel2abs( $excludedir);
     }
-    elsif($self->metadata_path_arr > $self->payload_path_arr && -d _ && $_ eq $self->rel_metadata_path) {
-        #print "pruning ".$File::Find::name."\n";
-        $File::Find::prune=1;
-    }
-    else {
-        #payload directories
-    }
-    #print "name: ".$File::Find::name."\n";
-  }, $payload_dir);
-  @payload = sort @ payload;
-  return wantarray ? @payload : \@payload;
-
+    my @file_paths;
+    my $finder;
+    $finder = sub {
+        my $current_dir = shift; #absolute path
+        my @todo;
+        opendir( my $dh, $current_dir);
+        while ( my $local_entry = readdir($dh) ) {
+            next if $local_entry =~ m/^\.{1,2}$/;
+            my $hexdump = "0x".unpack('H*', $local_entry);
+            utf8::downgrade($local_entry);
+            my $local_entry_utf8 = decode("UTF-8", $local_entry);
+            if ((! $self->has_force_utf8) && ($local_entry !~ /^[a-zA-Z0-9._-]+$/)) {
+                carp "possible non portable pathname detected in $dir, got path (hexdump)='$hexdump'(hex),  decoded path='$local_entry_utf8'\n";
+            }
+            my $path_entry = File::Spec->catdir($current_dir, $local_entry_utf8);
+            if (-f $path_entry) {
+                push @file_paths, $path_entry;
+            } elsif (-d $path_entry) {
+                next if ((defined $excludedir) && ($path_entry eq $excludedir));
+                push @todo, $path_entry;
+            } else {
+                croak "not a file nor a dir found '$path_entry'";
+            }
+        }
+        closedir($dh);
+        foreach my $subdir (@todo) {
+            &$finder($subdir);
+        }
+    };
+    my $absolute = File::Spec->rel2abs( $dir );
+    &$finder($absolute);
+    @file_paths = map { File::Spec->abs2rel( $_, $dir)} @file_paths;
+    return @file_paths;
 }
 
+sub _build_payload_files{
+    my ($self) = @_;
+    my $payload_dir = $self->payload_path;
+    my $reldir = File::Spec->abs2rel($payload_dir, $self->bag_path());
+    $reldir =~ s/^\.$//;
+    my @payload = sort map {
+        $reldir eq "" ? $_ : File::Spec->catfile($reldir, $_)
+    } $self->__file_find($payload_dir, File::Spec->rel2abs($self->metadata_path));
+    return wantarray ? @payload : \@payload;
+}
+
+
 sub __build_read_bagit_txt {
     my($self) = @_;
     my $bagit = $self->metadata_path;
-    my $file = File::Spec->catdir($bagit, "bagit.txt");
-    open(my $BAGIT, "<", $file) or croak("Cannot read '$file': $!");
+    my $file = File::Spec->catfile($bagit, "bagit.txt");
+    open(my $BAGIT, "<:encoding(UTF-8)", $file) or croak("Cannot read '$file': $!");
     my $version_string = <$BAGIT>;
     my $encoding_string = <$BAGIT>;
     close($BAGIT);
@@ -398,13 +597,12 @@ sub __build_read_bagit_txt {
     return ($version_string, $encoding_string, $file);
 }
 
-
 sub _build_bag_version {
     my($self) = @_;
     my ($version_string, $encoding_string, $file) = $self->__build_read_bagit_txt();
     croak "Version line missed in '$file" unless defined $version_string;
     if ($version_string =~ /^BagIt-Version: ([01]\.[0-9]+)$/) {
-        return $1
+        return $1;
     } else {
         $version_string =~ s/\r/<CR>/;
         $version_string =~ s/^\N{U+FEFF}/<BOM>/;
@@ -487,9 +685,9 @@ sub _parse_bag_info { # parses a bag-info textblob
 sub _build_bag_info {
     my ($self) = @_;
     my $bagit = $self->metadata_path;
-    my $file = File::Spec->catdir($bagit, "bag-info.txt");
+    my $file = File::Spec->catfile($bagit, "bag-info.txt");
     if (-e $file) {
-        open(my $BAGINFO, "<", $file) or croak("Cannot read $file: $!");
+        open(my $BAGINFO, "<:encoding(UTF-8)", $file) or croak("Cannot read $file: $!");
         my @lines;
         foreach my $line (<$BAGINFO>) {
             push @lines, $line;
@@ -503,28 +701,14 @@ sub _build_bag_info {
 }
 
 sub _build_non_payload_files {
-  my($self) = @_;
-  my @non_payload = ();
-  File::Find::find( sub{
-    $File::Find::name = decode('utf8', $File::Find::name);
-    $_=decode ('utf8', $_);
-    if (-f $_) {
-        my $rel_path=File::Spec->catdir($self->rel_metadata_path,File::Spec->abs2rel($File::Find::name, $self->metadata_path));
-        #print "pushing ".$rel_path." payload_dir: $payload_dir \n";
-        push(@non_payload,$rel_path);
-    }
-    elsif($self->metadata_path_arr < $self->payload_path_arr && -d _ && $_ eq $self->rel_payload_path) {
-        #print "pruning ".$File::Find::name."\n";
-        $File::Find::prune=1;
-    }
-    else {
-        #payload directories
-    }
-    #print "name: ".$File::Find::name."\n";
-  }, $self->metadata_path);
-  @non_payload = sort @non_payload;
-  return wantarray ? @non_payload : \@non_payload;
-
+    my ($self) = @_;
+    my $non_payload_dir = $self->metadata_path();
+    my $reldir = File::Spec->abs2rel($non_payload_dir, $self->bag_path());
+    $reldir =~ s/^\.$//;
+    my @non_payload = sort map {
+        $reldir eq "" ? $_ : File::Spec->catfile($reldir, $_)
+    } $self->__file_find($non_payload_dir, File::Spec->rel2abs($self->payload_path));
+    return wantarray ? @non_payload : \@non_payload;
 }
 
 sub _build_forced_fixity_algorithm {
@@ -537,6 +721,8 @@ sub _build_forced_fixity_algorithm {
     }
 }
 
+###############################################
+
 
 sub load_plugins {
     my ($self, @plugins) = @_;
@@ -554,6 +740,9 @@ sub load_plugins {
     return 1;
 }
 
+###############################################
+
+
 sub load {
     my ($self) = @_;
     # call trigger
@@ -568,7 +757,7 @@ sub load {
     return 1;
 }
 
-
+###############################################
 
 
 sub verify_bag {
@@ -578,10 +767,10 @@ sub verify_bag {
     my $bagit = $self->bag_path;
     my $version = $self->bag_version(); # to call trigger
     my $encoding = $self->bag_encoding(); # to call trigger
-    my $baginfo = $self->bag_info(); #to call trigger
+    my $baginfo = $self->verify_baginfo(); #to call trigger
     my $forced_fixity_alg = $self->forced_fixity_algorithm()->name();
-    my $fetch_file = File::Spec->catdir($self->metadata_path, "fetch.txt");
-    my $manifest_file = File::Spec->catdir($self->metadata_path, "manifest-$forced_fixity_alg.txt");
+    my $fetch_file = File::Spec->catfile($self->metadata_path, "fetch.txt");
+    my $manifest_file = File::Spec->catfile($self->metadata_path, "manifest-$forced_fixity_alg.txt");
     my $payload_dir   = $self->payload_path;
     my $return_all_errors = $opts->{return_all_errors};
 
@@ -602,6 +791,7 @@ sub verify_bag {
         my $res = $self->manifests->{$algorithm}->verify_manifest($self->payload_files, $return_all_errors);
         if ((defined $res) && ($res ne "1")) { push @errors, $res; }
     }
+
     foreach my $algorithm ( keys %{ $self->manifests }) {
         my $res = $self->manifests->{$algorithm}->verify_tagmanifest($self->non_payload_files, $return_all_errors);
         if ((defined $res) && ($res ne "1")) { push @errors, $res; }
@@ -622,8 +812,8 @@ sub calc_payload_oxum {
     my $octets=0;
     my $streamcount = scalar @payload;
     foreach my $local_name (@payload) {# local_name is relative to bagit base
-        my $file = File::Spec->catdir($self->bag_path(), $local_name);
-        my $sb = stat($file);
+        my $file = File::Spec->catfile($self->bag_path(), $local_name);
+        my $sb = File::stat::stat($file) or croak "file $file error, $!";
         $octets += $sb->size;
     }
     return ($octets, $streamcount);
@@ -644,8 +834,8 @@ sub calc_bagsize {
 sub create_bagit {
     my($self) = @_;
     my $metadata_path = $self->metadata_path();
-    my $bagit_path = File::Spec->catdir( $metadata_path, "bagit.txt");
-    open(my $BAGIT, ">", $bagit_path) or croak("Can't open $bagit_path for writing: $!");
+    my $bagit_path = File::Spec->catfile( $metadata_path, "bagit.txt");
+    open(my $BAGIT, ">:encoding(UTF-8)", $bagit_path) or croak("Can't open $bagit_path for writing: $!");
     print($BAGIT "BagIt-Version: 1.0\nTag-File-Character-Encoding: UTF-8");
     close($BAGIT);
     return 1;
@@ -654,18 +844,18 @@ sub create_bagit {
 
 sub create_baginfo {
     my($self) = @_; # because bag-info.txt allows multiple key-value-entries, hash is replaced
-    $self->_add_or_replace_bag_info('Bagging-Date', POSIX::strftime("%F", gmtime(time)));
-    $self->_add_or_replace_bag_info('Bag-Software-Agent', 'Archive::BagIt <https://metacpan.org/pod/Archive::BagIt>');
+    $self->add_or_replace_baginfo_by_key('Bagging-Date', POSIX::strftime("%Y-%m-%d", gmtime(time)));
+    $self->add_or_replace_baginfo_by_key('Bag-Software-Agent', 'Archive::BagIt <https://metacpan.org/pod/Archive::BagIt>');
     my ($octets, $streams) = $self->calc_payload_oxum();
-    $self->_add_or_replace_bag_info('Payload-Oxum', "$octets.$streams");
-    $self->_add_or_replace_bag_info('Bag-Size', $self->calc_bagsize());
+    $self->add_or_replace_baginfo_by_key('Payload-Oxum', "$octets.$streams");
+    $self->add_or_replace_baginfo_by_key('Bag-Size', $self->calc_bagsize());
     # The RFC does not allow reordering:
     my $metadata_path = $self->metadata_path();
-    my $bag_info_path = File::Spec->catdir( $metadata_path, "bag-info.txt");
-    open(my $BAGINFO, ">", $bag_info_path) or croak("Can't open $bag_info_path for writing: $!");
+    my $bag_info_path = File::Spec->catfile( $metadata_path, "bag-info.txt");
+    open(my $BAGINFO, ">:encoding(UTF-8)", $bag_info_path) or croak("Can't open $bag_info_path for writing: $!");
     foreach my $entry (@{ $self->bag_info() }) {
         my %tmp = %{ $entry };
-        my ($key, $value) = each %tmp;
+        my ($key, $value) = %tmp;
         if ($key =~ m/:/) { carp "key should not contain a colon! (searchkey='$key')"; }
         print($BAGINFO "$key: $value\n");
     }
@@ -708,7 +898,6 @@ sub init_metadata {
         #metadata path is not the root path for some reason
         mkdir ($self->metadata_path);
     }
-
     $self->store();
     # FIXME: deprecated?
     #foreach my $algorithm (keys %{$self->manifests}) {
@@ -733,6 +922,7 @@ sub make_bag {
 }
 
 
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -745,88 +935,16 @@ __END__
 
 =head1 NAME
 
-Archive::BagIt::Base
+Archive::BagIt::Base - The common base for Archive::BagIt. This is the module for experts. ;)
 
 =head1 VERSION
 
-version 0.061
-
-=head1 SYNOPSIS
-
-This modules will hopefully help with the basic commands needed to create
-and verify a bag. This part supports BagIt 1.0 according to RFC 8493 ([https://tools.ietf.org/html/rfc8493](https://tools.ietf.org/html/rfc8493)).
-
-You only need to know the following methods first:
-
-=head2 read a BagIt
-
-    use Archive::BagIt::Base;
-
-    #read in an existing bag:
-    my $bag_dir = "/path/to/bag";
-    my $bag = Archive::BagIt::Base->new($bag_dir);
-
-=head2 construct a BagIt around a payload
-
-    use Archive::BagIt::Base;
-    my $bag2 = Archive::BagIt::Base->make_bag($bag_dir);
-
-=head2 verify a BagIt-dir
-
-    use Archive::BagIt::Base;
-
-    # Validate a BagIt archive against its manifest
-    my $bag3 = Archive::BagIt::Base->new($bag_dir);
-    my $is_valid1 = $bag3->verify_bag();
-
-    # Validate a BagIt archive against its manifest, report all errors
-    my $bag4 = Archive::BagIt::Base->new($bag_dir);
-    my $is_valid2 = $bag4->verify_bag( {report_all_errors => 1} );
-
-=head2 read a BagIt-dir, change something, store
-
-Because all methods operate lazy, you should ensure to parse parts of the bag *BEFORE* you modify it.
-Otherwise it will be overwritten!
-
-    use Archive::BagIt::Base;
-    my $bag5 = Archive::BagIt::Base->new($bag_dir); # lazy, nothing happened
-    $bag5->load(); # this updates the object representation by parsing the given $bag_dir
-    $bag5->store(); # this writes the bag new
-
-=head1 NAME
-
-Archive::BagIt::Base
-
-=head1 VERSION
-
-version 0.061
+version 0.064
 
 =head1 NAME
 
 Achive::BagIt::Base - The common base for both Bagit and dotBagIt
 
-=head1 AUTHORS
-
-=over
-
-=item Robert Schmidt, E<lt>rjeschmi at gmail.comE<gt>
-
-=item William Wueppelmann, E<lt>william at c7a.caE<gt>
-
-=item Andreas Romeyke, E<lt>pause at andreas minus romeyke.deE<gt>
-
-=back
-
-=head1 CONTRIBUTORS
-
-=over
-
-=item Serhiy Bolkun
-
-=item Russell McOrmond
-
-=back
-
 =head1 SOURCE
 
 The original development version was on github at L<http://github.com/rjeschmi/Archive-BagIt>
@@ -919,6 +1037,54 @@ You could try this:
    $bag->load();
    $bag->store();
 
+=head2 How to create UTF-8 based paths under MS Windows?
+
+I have no idea and suggestions for a portable solution are very welcome!
+
+Hint: The better way is to use only portable filenames. See L<perlport> for details.
+
+=head1 SYNOPSIS
+
+This modules will hopefully help with the basic commands needed to create
+and verify a bag. This part supports BagIt 1.0 according to RFC 8493 ([https://tools.ietf.org/html/rfc8493](https://tools.ietf.org/html/rfc8493)).
+
+You only need to know the following methods first:
+
+=head2 read a BagIt
+
+    use Archive::BagIt::Base;
+
+    #read in an existing bag:
+    my $bag_dir = "/path/to/bag";
+    my $bag = Archive::BagIt::Base->new($bag_dir);
+
+=head2 construct a BagIt around a payload
+
+    use Archive::BagIt::Base;
+    my $bag2 = Archive::BagIt::Base->make_bag($bag_dir);
+
+=head2 verify a BagIt-dir
+
+    use Archive::BagIt::Base;
+
+    # Validate a BagIt archive against its manifest
+    my $bag3 = Archive::BagIt::Base->new($bag_dir);
+    my $is_valid1 = $bag3->verify_bag();
+
+    # Validate a BagIt archive against its manifest, report all errors
+    my $bag4 = Archive::BagIt::Base->new($bag_dir);
+    my $is_valid2 = $bag4->verify_bag( {report_all_errors => 1} );
+
+=head2 read a BagIt-dir, change something, store
+
+Because all methods operate lazy, you should ensure to parse parts of the bag *BEFORE* you modify it.
+Otherwise it will be overwritten!
+
+    use Archive::BagIt::Base;
+    my $bag5 = Archive::BagIt::Base->new($bag_dir); # lazy, nothing happened
+    $bag5->load(); # this updates the object representation by parsing the given $bag_dir
+    $bag5->store(); # this writes the bag new
+
 =head1 METHODS
 
 =head2 Constructor
@@ -961,6 +1127,12 @@ See C<load()> if you want to parse/modify an existing bag.
 
 to check if parallelization is possible.
 
+=head2 has_force_utf8()
+
+to check if force_utf8() was set.
+
+If set it ignores warnings about potential filepath problems.
+
 =head2 bag_path([$new_value])
 
 Getter/setter for bag path
@@ -1010,9 +1182,71 @@ which is implemented by each C<Archive::BagIt::Plugin::Algorithm::XXXX> module.
 
 See C<Archive::BagIt::Fast> for details.
 
-=head2 bag_info_by_key($searchkey)
+=head2 get_baginfo_values_by_key($searchkey)
 
-TODO: Returns all values which match $searchkeyx
+Returns all values which match $searchkey, undef otherwise
+
+=head2 is_baginfo_key_reserved_as_uniq($searchkey)
+
+returns true if key is reserved and should be uniq
+
+=head2 is_baginfo_key_reserved( $searchkey )
+
+returns true if key is reserved
+
+=head2 verify_baginfo()
+
+checks baginfo-keys, returns true if all fine, otherwise returns undef and the message is pushed to C<errors()>.
+
+=head2 delete_baginfo_by_key( $searchkey )
+
+deletes an entry of given $searchkey if exists
+
+=head2 exists_baginfo_key( $searchkey )
+
+returns true if a given $searchkey exists
+
+=head2 append_baginfo_by_key($searchkey, $newvalue)
+
+Appends a key value pair to bag_info.
+
+HINT: check return code if append was successful, because some keys needs to be uniq.
+
+=head2 add_or_replace_baginfo_by_key($searchkey, $newvalue)
+
+It replaces the first entry with $newvalue if $searchkey exists, otherwise it appends.
+
+=head2 forced_fixity_algorithm()
+
+Getter to return the forced fixity algorithm depending on BagIt version
+
+=head2 manifest_files()
+
+Getter to find all manifest-files
+
+=head2 tagmanifest_files()
+
+Getter to find all tagmanifest-files
+
+=head2 payload_files()
+
+Getter to find all payload-files
+
+=head2 non_payload_files()
+
+Getter to find all non payload-files
+
+=head2 plugins()
+
+Getter/setter to algorithm plugins
+
+=head2 manifests()
+
+Getter/Setter to all manifests (objects)
+
+=head2 algos()
+
+Getter/Setter to all registered Algorithms
 
 =head2 load_plugins
 
@@ -1047,6 +1281,9 @@ creates a bagit.txt file
 
 creates a bag-info.txt file
 
+Hint: the entries 'Bagging-Date', 'Bag-Software-Agent', 'Payload-Oxum' and 'Bag-Size' will be automagically set,
+existing values in internal bag-info representation will be overwritten!
+
 =head2 store()
 
 store a bagit-obj if bagit directory-structure was already constructed.
@@ -1070,11 +1307,6 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<https://metacpan.org/module/Archive::BagIt/>.
 
-=head1 SOURCE
-
-The development version is on github at L<https://github.com/Archive-BagIt>
-and may be cloned from L<git://github.com/Archive-BagIt.git>
-
 =head1 BUGS AND LIMITATIONS
 
 You can make new bug reports, and view existing ones, through the
@@ -1091,15 +1323,4 @@ This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and A
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 AUTHOR
-
-Rob Schmidt <rjeschmi@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
