@@ -7,7 +7,7 @@ use Time::HiRes qw(time);
 use Moo;
 extends "Archive::BagIt::Base";
 
-our $VERSION = '0.061'; # TRIAL VERSION
+our $VERSION = '0.064'; # TRIAL VERSION
 
 
 has 'digest_callback' => (
@@ -61,15 +61,7 @@ Archive::BagIt::Fast
 
 =head1 VERSION
 
-version 0.061
-
-=head1 NAME
-
-Archive::BagIt::Fast
-
-=head1 VERSION
-
-version 0.061
+version 0.064
 
 =head1 NAME
 
@@ -97,11 +89,6 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<https://metacpan.org/module/Archive::BagIt/>.
 
-=head1 SOURCE
-
-The development version is on github at L<https://github.com/Archive-BagIt>
-and may be cloned from L<git://github.com/Archive-BagIt.git>
-
 =head1 BUGS AND LIMITATIONS
 
 You can make new bug reports, and view existing ones, through the
@@ -118,15 +105,4 @@ This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and A
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 AUTHOR
-
-Rob Schmidt <rjeschmi@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
