@@ -1,4 +1,4 @@
-#ABSTRACT: The default MD5 algorithm plugin
+#ABSTRACT: The MD5 algorithm plugin (default for v0.97)
 package Archive::BagIt::Plugin::Algorithm::MD5;
 use strict;
 use warnings;
@@ -50,7 +50,7 @@ sub get_hash_string {
 
 sub verify_file {
     my ($self, $filename) = @_;
-    open(my $fh, '<', $filename) || croak ("Can't open '$filename', $!");
+    open(my $fh, '<:raw', $filename) || croak ("Can't open '$filename', $!");
     binmode($fh);
     my $digest = $self->get_hash_string($fh);
     close $fh || croak("could not close file '$filename', $!");
@@ -67,19 +67,11 @@ __END__
 
 =head1 NAME
 
-Archive::BagIt::Plugin::Algorithm::MD5 - The default MD5 algorithm plugin
+Archive::BagIt::Plugin::Algorithm::MD5 - The MD5 algorithm plugin (default for v0.97)
 
 =head1 VERSION
 
-version 0.061
-
-=head1 NAME
-
-Archive::BagIt::Plugin::Algorithm::MD5 - The default MD5 algorithm plugin
-
-=head1 VERSION
-
-version 0.061
+version 0.064
 
 =head1 AVAILABILITY
 
@@ -87,11 +79,6 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<https://metacpan.org/module/Archive::BagIt/>.
 
-=head1 SOURCE
-
-The development version is on github at L<https://github.com/Archive-BagIt>
-and may be cloned from L<git://github.com/Archive-BagIt.git>
-
 =head1 BUGS AND LIMITATIONS
 
 You can make new bug reports, and view existing ones, through the
@@ -108,15 +95,4 @@ This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and A
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 AUTHOR
-
-Rob Schmidt <rjeschmi@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
