@@ -1,4 +1,4 @@
-#ABSTRACT: The md5 plugin (default)
+#ABSTRACT: The role to load md5 plugin (default for v0.97)
 package Archive::BagIt::Plugin::Manifest::MD5;
 use strict;
 use warnings;
@@ -52,19 +52,11 @@ __END__
 
 =head1 NAME
 
-Archive::BagIt::Plugin::Manifest::MD5 - The md5 plugin (default)
+Archive::BagIt::Plugin::Manifest::MD5 - The role to load md5 plugin (default for v0.97)
 
 =head1 VERSION
 
-version 0.061
-
-=head1 NAME
-
-Archive::BagIt::Plugin::Manifest::MD5 - The md5 plugin (default)
-
-=head1 VERSION
-
-version 0.061
+version 0.064
 
 =head1 AVAILABILITY
 
@@ -72,11 +64,6 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<https://metacpan.org/module/Archive::BagIt/>.
 
-=head1 SOURCE
-
-The development version is on github at L<https://github.com/Archive-BagIt>
-and may be cloned from L<git://github.com/Archive-BagIt.git>
-
 =head1 BUGS AND LIMITATIONS
 
 You can make new bug reports, and view existing ones, through the
@@ -93,15 +80,4 @@ This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and A
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 AUTHOR
-
-Rob Schmidt <rjeschmi@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
