@@ -22,7 +22,7 @@ has 'manifest_file' => (
 sub _build_manifest_file {
     my $self = shift;
     my $algorithm = $self->algorithm()->name;
-    my $file = File::Spec->catdir($self->bagit->metadata_path, "manifest-$algorithm.txt");
+    my $file = File::Spec->catfile($self->bagit->metadata_path, "manifest-$algorithm.txt");
     if (-f $file) {
         return $file;
     }
@@ -39,7 +39,7 @@ has 'tagmanifest_file' => (
 sub _build_tagmanifest_file {
     my $self = shift;
     my $algorithm = $self->algorithm()->name;
-    my $file = File::Spec->catdir( $self->bagit->metadata_path, "tagmanifest-$algorithm.txt");
+    my $file = File::Spec->catfile( $self->bagit->metadata_path, "tagmanifest-$algorithm.txt");
     if (-f $file) {
         return $file;
     }
@@ -79,7 +79,7 @@ has 'tagmanifest_entries' => (
 sub __build_xxxmanifest_entries {
     my ($self, $xxmanifest_file) = @_;
     my $xxmanifest_entries = {};
-    open(my $XXMANIFEST, "<:encoding(utf8)", $xxmanifest_file) or croak("Cannot open $xxmanifest_file: $!");
+    open(my $XXMANIFEST, "<:encoding(UTF-8)", $xxmanifest_file) or croak("Cannot open $xxmanifest_file: $!");
     my $algorithm = $self->algorithm()->name;
     while (my $line = <$XXMANIFEST>) {
         chomp($line);
@@ -140,7 +140,7 @@ sub check_if_payload_filepath_violates{
 sub _fill_digest_hashref {
     my ($self, $bagit, $digestobj, $localname) = @_;
     my $digest_hashref;
-    my $fullname = File::Spec->catdir($bagit, $localname);
+    my $fullname = File::Spec->catfile($bagit, $localname);
     my $calc_digest = $self->bagit->digest_callback();
     $digest_hashref->{calculated_digest} = &$calc_digest($digestobj, $fullname);
     $digest_hashref->{local_name} = $localname;
@@ -208,7 +208,7 @@ sub _verify_XXX_manifests {
     # Test readability
     foreach my $local_name (@files) {
         # local_name is relative to bagit base
-        my $filepath = File::Spec->catdir($bagit, $local_name);
+        my $filepath = File::Spec->catfile($bagit, $local_name);
         unless (-r $filepath) {
             &$subref_invalid_report_or_die(
                 "cannot read $local_name (bag-path:$bagit)",
@@ -256,7 +256,7 @@ sub _verify_XXX_manifests {
             #use Data::Printer; p( $digest_entry); p( $local_xxfilename);p( $algorithm);p($normalized);
             if (! defined $digest_entry->{expected_digest} ) { next; } # undef expected digests only occur if all preconditions fullfilled but return_all_errors was set, we should ignore it!
             if ($digest_entry->{calculated_digest} ne $digest_entry->{expected_digest}) {
-                my $xxfilename = File::Spec->catdir($bagit, $local_xxfilename);
+                my $xxfilename = File::Spec->catfile($bagit, $local_xxfilename);
                 &$subref_invalid_report_or_die(
                     sprintf("file '%s' (normalized='%s') invalid, digest (%s) calculated=%s, but expected=%s in file '%s'",
                         $digest_entry->{local_name},
@@ -313,16 +313,20 @@ sub verify_tagmanifest {
 sub __create_xxmanifest {
     my ($self, $prefix, $files_ref) = @_;
     my $algo = $self->algorithm->name;
-    my $manifest_file = File::Spec->catdir($self->bagit->metadata_path, "$prefix-${algo}.txt");
+    my $digestobj = $self->algorithm;
+    my $bagit = $self->bagit->bag_path;
+    my $manifest_file = File::Spec->catfile($self->bagit->metadata_path, "$prefix-${algo}.txt");
     # Generate digests for all of the files under ./data
-    open(my $fh, ">",$manifest_file) or croak("Cannot create $prefix-${algo}.txt: $!\n");
-    foreach my $rel_file (@{$files_ref}) {
-        my $file = File::Spec->catdir($self->bagit->bag_path, $rel_file);
-        my $digest = $self->algorithm->verify_file( $file );
-        my $normalized_file = normalize_payload_filepath($rel_file);
-        print($fh "$digest  $normalized_file\n");
+    my $digest_hashes_ref = $self->calc_digests($bagit, $digestobj, $files_ref);
+    if (defined $digest_hashes_ref && (ref $digest_hashes_ref eq 'ARRAY')) {
+        open(my $fh, ">:encoding(UTF-8)",$manifest_file) or croak("Cannot create $prefix-${algo}.txt: $!\n");
+        foreach my $digest_entry (@{$digest_hashes_ref}) {
+            my $normalized_file = normalize_payload_filepath($digest_entry->{local_name});
+            my $digest = $digest_entry->{calculated_digest};
+            print($fh "$digest  $normalized_file\n");
+        }
+        close($fh);
     }
-    close($fh);
     return 1;
 }
 
@@ -356,15 +360,7 @@ Archive::BagIt::Role::Manifest - A role that handles all manifest files for a sp
 
 =head1 VERSION
 
-version 0.061
-
-=head1 NAME
-
-Archive::BagIt::Role::Manifest - A role that handles all manifest files for a specific Algorithm
-
-=head1 VERSION
-
-version 0.061
+version 0.064
 
 =head2 calc_digests($bagit, $digestobj, $filenames_ref, $opts)
 
@@ -394,11 +390,6 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<https://metacpan.org/module/Archive::BagIt/>.
 
-=head1 SOURCE
-
-The development version is on github at L<https://github.com/Archive-BagIt>
-and may be cloned from L<git://github.com/Archive-BagIt.git>
-
 =head1 BUGS AND LIMITATIONS
 
 You can make new bug reports, and view existing ones, through the
@@ -415,15 +406,4 @@ This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and A
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 AUTHOR
-
-Rob Schmidt <rjeschmi@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
