@@ -1,4 +1,5 @@
 package Archive::BagIt::Role::Plugin;
+# ABSTRACT: A role that handles plugin loading
 use strict;
 use warnings;
 use Moo::Role;
@@ -34,19 +35,11 @@ __END__
 
 =head1 NAME
 
-Archive::BagIt::Role::Plugin
+Archive::BagIt::Role::Plugin - A role that handles plugin loading
 
 =head1 VERSION
 
-version 0.061
-
-=head1 NAME
-
-Archive::BagIt::Role::Plugin
-
-=head1 VERSION
-
-version 0.061
+version 0.064
 
 =head1 AVAILABILITY
 
@@ -54,11 +47,6 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<https://metacpan.org/module/Archive::BagIt/>.
 
-=head1 SOURCE
-
-The development version is on github at L<https://github.com/Archive-BagIt>
-and may be cloned from L<git://github.com/Archive-BagIt.git>
-
 =head1 BUGS AND LIMITATIONS
 
 You can make new bug reports, and view existing ones, through the
@@ -75,15 +63,4 @@ This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and A
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 AUTHOR
-
-Rob Schmidt <rjeschmi@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
